translate.convert.php2po.php2po

Package translate :: Package convert :: Module php2po :: Class php2po |
[hide private]
[frames] | no frames]

# Class php2po

source code

convert a .php file to a .po file for handling the translation...

Instance Methods | [hide private]
convertstore(self, inputstore, duplicatestyle="msgctxt") converts a .php file to a .po file... | source code
mergestore(self, templatestore, inputstore, blankmsgstr=False, duplicatestyle="msgctxt") converts two .properties files to a .po file... | source code
convertunit(self, inputunit, origin) Converts a .php unit to a .po unit | source code